# Errors (E)

Errors indicate problems that will prevent a skill from working correctly. These must be fixed.

| Code | Description                                         |
|------|-----------------------------------------------------|
| E001 | Missing `SKILL.md` manifest file                    |
| E002 | Malformed YAML frontmatter (syntax error)           |
| E003 | Missing required `name` field in frontmatter        |
| E004 | Missing required `description` field in frontmatter |
| E005 | `name` field violates kebab-case naming convention  |
